'''
## This file is autogenerated from macrosynergy setup.py.

It contains version information for the macrosynergy package.

short_version: 1.1.1

version: 1.1.1

full_version: 1.1.1

git_revision: 713cbc6ed00f599aea04ccfd9964af2514c7874f

release: True

'''
short_version: str = '1.1.1'
version: str = '1.1.1'
full_version: str = '1.1.1'
git_revision: str = '713cbc6ed00f599aea04ccfd9964af2514c7874f'
release: bool = True
if not release:
    version = full_version
